@@ -137,7 +137,7 @@ def get_patches_test_features(img, patch_size, stride=8):
 
 def extract_on_patches(img, patch_size):
     h, w = img.shape
-    patch_size = np.int(patch_size)
+    patch_size = int(patch_size)
     patches = []
     for j in range(0, h-patch_size+1, patch_size):
         for i in range(0, w-patch_size+1, patch_size):
@@ -171,7 +171,9 @@ def _get_patches_generic(img, patch_size, is_train, stride):
 
     img = img.astype(np.float32)
     # img2 = scipy.misc.imresize(img, 0.5, interp='bicubic', mode='F')
-    img2 = np.array(Image.fromarray(img).resize(((np.size(img,1)/2),(np.size(img,0)/2))))
+    img2_width = int(np.round((np.size(img,1)/2),0))
+    img2_height = int(np.round((np.size(img,0)/2),0))
+    img2 = np.array(Image.fromarray(img).resize((img2_width,img2_height)))
 
     mscn1, var, mu = compute_image_mscn_transform(img)
     mscn1 = mscn1.astype(np.float32)
